@@ -28,7 +28,10 @@ import hwrt.create_pfiles as create_pfiles
 def _fetch_data_from_server(raw_data_id, mysql_cfg):
     """Get the data from raw_data_id from the server.
     :returns: The ``data`` if fetching worked, ``None`` if it failed."""
-    import MySQLdb
+    try:
+        import MySQLdb
+    except ImportError:
+        import pymysql as MySQLdb
     import MySQLdb.cursors
 
     # Import configuration file
